@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2023, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
 
-require_relative 'extension/compression'
-require_relative 'headers'
+require_relative "extension/compression"
+require_relative "headers"
 
 module Protocol
 	module WebSocket
@@ -16,7 +16,7 @@ module Protocol
 					name, *arguments = header.split(/\s*;\s*/)
 					
 					arguments = arguments.map do |argument|
-						argument.split('=', 2)
+						argument.split("=", 2)
 					end
 					
 					yield name, arguments
@@ -65,6 +65,8 @@ module Protocol
 							@accepted << [klass, options]
 						end
 					end
+					
+					return @accepted
 				end
 				
 				def apply(connection)
@@ -112,14 +114,14 @@ module Protocol
 								# The extension is accepted and no further offers will be considered:
 								named.delete(name)
 								
-								yield header
+								yield header if block_given?
 								
 								@accepted << [klass, options]
 							end
 						end
 					end
 					
-					return headers
+					return @accepted
 				end
 				
 				def apply(connection)
