@@ -1,12 +1,13 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'frame'
+require_relative "frame"
 
 module Protocol
 	module WebSocket
+		# Represents a pong frame that is sent or received by a WebSocket connection.
 		class PongFrame < Frame
 			OPCODE = 0xA
 			
